@@ -12,7 +12,7 @@ var searchData=
   ['calendar2_9',['Calendar2',['../structcom_1_1sun_1_1star_1_1i18n_1_1Calendar2.html',1,'com::sun::star::i18n']]],
   ['calendaritem_10',['CalendarItem',['../structcom_1_1sun_1_1star_1_1i18n_1_1CalendarItem.html',1,'com::sun::star::i18n']]],
   ['calendaritem2_11',['CalendarItem2',['../structcom_1_1sun_1_1star_1_1i18n_1_1CalendarItem2.html',1,'com::sun::star::i18n']]],
-  ['callablestatement_12',['callablestatement',['../servicecom_1_1sun_1_1star_1_1sdb_1_1CallableStatement.html',1,'CallableStatement'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1CallableStatement.html',1,'CallableStatement']]],
+  ['callablestatement_12',['CallableStatement',['../servicecom_1_1sun_1_1star_1_1sdb_1_1CallableStatement.html',1,'CallableStatement'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1CallableStatement.html',1,'CallableStatement']]],
   ['camerageometry_13',['CameraGeometry',['../structcom_1_1sun_1_1star_1_1drawing_1_1CameraGeometry.html',1,'com::sun::star::drawing']]],
   ['candlestickcharttype_14',['CandleStickChartType',['../servicecom_1_1sun_1_1star_1_1chart2_1_1CandleStickChartType.html',1,'com::sun::star::chart2']]],
   ['cannotactivatefactoryexception_15',['CannotActivateFactoryException',['../exceptioncom_1_1sun_1_1star_1_1loader_1_1CannotActivateFactoryException.html',1,'com::sun::star::loader']]],
@@ -27,7 +27,7 @@ var searchData=
   ['caret_24',['Caret',['../structcom_1_1sun_1_1star_1_1rendering_1_1Caret.html',1,'com::sun::star::rendering']]],
   ['cartesiancoordinatesystem2d_25',['CartesianCoordinateSystem2d',['../servicecom_1_1sun_1_1star_1_1chart2_1_1CartesianCoordinateSystem2d.html',1,'com::sun::star::chart2']]],
   ['cartesiancoordinatesystem3d_26',['CartesianCoordinateSystem3d',['../servicecom_1_1sun_1_1star_1_1chart2_1_1CartesianCoordinateSystem3d.html',1,'com::sun::star::chart2']]],
-  ['cell_27',['cell',['../servicecom_1_1sun_1_1star_1_1table_1_1Cell.html',1,'Cell'],['../servicecom_1_1sun_1_1star_1_1text_1_1Cell.html',1,'Cell']]],
+  ['cell_27',['Cell',['../servicecom_1_1sun_1_1star_1_1table_1_1Cell.html',1,'Cell'],['../servicecom_1_1sun_1_1star_1_1text_1_1Cell.html',1,'Cell']]],
   ['celladdress_28',['CellAddress',['../structcom_1_1sun_1_1star_1_1table_1_1CellAddress.html',1,'com::sun::star::table']]],
   ['cellannotation_29',['CellAnnotation',['../servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotation.html',1,'com::sun::star::sheet']]],
   ['cellannotations_30',['CellAnnotations',['../servicecom_1_1sun_1_1star_1_1sheet_1_1CellAnnotations.html',1,'com::sun::star::sheet']]],
@@ -40,9 +40,9 @@ var searchData=
   ['cellcursor_37',['CellCursor',['../servicecom_1_1sun_1_1star_1_1table_1_1CellCursor.html',1,'com::sun::star::table']]],
   ['cellformatranges_38',['CellFormatRanges',['../servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRanges.html',1,'com::sun::star::sheet']]],
   ['cellformatrangesenumeration_39',['CellFormatRangesEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRangesEnumeration.html',1,'com::sun::star::sheet']]],
-  ['cellproperties_40',['cellproperties',['../servicecom_1_1sun_1_1star_1_1table_1_1CellProperties.html',1,'CellProperties'],['../servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html',1,'CellProperties']]],
+  ['cellproperties_40',['CellProperties',['../servicecom_1_1sun_1_1star_1_1table_1_1CellProperties.html',1,'CellProperties'],['../servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html',1,'CellProperties']]],
   ['cellprotection_41',['CellProtection',['../structcom_1_1sun_1_1star_1_1util_1_1CellProtection.html',1,'com::sun::star::util']]],
-  ['cellrange_42',['cellrange',['../servicecom_1_1sun_1_1star_1_1table_1_1CellRange.html',1,'CellRange'],['../servicecom_1_1sun_1_1star_1_1text_1_1CellRange.html',1,'CellRange']]],
+  ['cellrange_42',['CellRange',['../servicecom_1_1sun_1_1star_1_1table_1_1CellRange.html',1,'CellRange'],['../servicecom_1_1sun_1_1star_1_1text_1_1CellRange.html',1,'CellRange']]],
   ['cellrangeaddress_43',['CellRangeAddress',['../structcom_1_1sun_1_1star_1_1table_1_1CellRangeAddress.html',1,'com::sun::star::table']]],
   ['cellrangelistsource_44',['CellRangeListSource',['../servicecom_1_1sun_1_1star_1_1table_1_1CellRangeListSource.html',1,'com::sun::star::table']]],
   ['cells_45',['Cells',['../servicecom_1_1sun_1_1star_1_1sheet_1_1Cells.html',1,'com::sun::star::sheet']]],
@@ -81,7 +81,7 @@ var searchData=
   ['chartdatarow_78',['ChartDataRow',['../structcom_1_1sun_1_1star_1_1chart_1_1ChartDataRow.html',1,'com::sun::star::chart']]],
   ['chartdatarowproperties_79',['ChartDataRowProperties',['../servicecom_1_1sun_1_1star_1_1chart_1_1ChartDataRowProperties.html',1,'com::sun::star::chart']]],
   ['chartdatavalue_80',['ChartDataValue',['../structcom_1_1sun_1_1star_1_1chart_1_1ChartDataValue.html',1,'com::sun::star::chart']]],
-  ['chartdocument_81',['chartdocument',['../servicecom_1_1sun_1_1star_1_1chart_1_1ChartDocument.html',1,'ChartDocument'],['../servicecom_1_1sun_1_1star_1_1chart2_1_1ChartDocument.html',1,'ChartDocument']]],
+  ['chartdocument_81',['ChartDocument',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ChartDocument.html',1,'ChartDocument'],['../servicecom_1_1sun_1_1star_1_1chart_1_1ChartDocument.html',1,'ChartDocument']]],
   ['chartdocumentwrapper_82',['ChartDocumentWrapper',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ChartDocumentWrapper.html',1,'com::sun::star::chart2']]],
   ['chartgrid_83',['ChartGrid',['../servicecom_1_1sun_1_1star_1_1chart_1_1ChartGrid.html',1,'com::sun::star::chart']]],
   ['chartlegend_84',['ChartLegend',['../servicecom_1_1sun_1_1star_1_1chart_1_1ChartLegend.html',1,'com::sun::star::chart']]],
@@ -97,7 +97,7 @@ var searchData=
   ['charttype_94',['ChartType',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ChartType.html',1,'com::sun::star::chart2']]],
   ['charttypemanager_95',['ChartTypeManager',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ChartTypeManager.html',1,'com::sun::star::chart2']]],
   ['charttypetemplate_96',['ChartTypeTemplate',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ChartTypeTemplate.html',1,'com::sun::star::chart2']]],
-  ['checkbox_97',['checkbox',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1CheckBox.html',1,'CheckBox'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CheckBox.html',1,'CheckBox']]],
+  ['checkbox_97',['CheckBox',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1CheckBox.html',1,'CheckBox'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CheckBox.html',1,'CheckBox']]],
   ['checkinargument_98',['CheckinArgument',['../structcom_1_1sun_1_1star_1_1ucb_1_1CheckinArgument.html',1,'com::sun::star::ucb']]],
   ['classifiedinteractionrequest_99',['ClassifiedInteractionRequest',['../exceptioncom_1_1sun_1_1star_1_1task_1_1ClassifiedInteractionRequest.html',1,'com::sun::star::task']]],
   ['classnotfoundexception_100',['ClassNotFoundException',['../exceptioncom_1_1sun_1_1star_1_1lang_1_1ClassNotFoundException.html',1,'com::sun::star::lang']]],
@@ -115,16 +115,16 @@ var searchData=
   ['colorscale_112',['ColorScale',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ColorScale.html',1,'com::sun::star::sheet']]],
   ['colorstop_113',['ColorStop',['../structcom_1_1sun_1_1star_1_1awt_1_1ColorStop.html',1,'com::sun::star::awt']]],
   ['colortable_114',['ColorTable',['../servicecom_1_1sun_1_1star_1_1drawing_1_1ColorTable.html',1,'com::sun::star::drawing']]],
-  ['column_115',['column',['../servicecom_1_1sun_1_1star_1_1sdb_1_1Column.html',1,'Column'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Column.html',1,'Column']]],
+  ['column_115',['Column',['../servicecom_1_1sun_1_1star_1_1sdb_1_1Column.html',1,'Column'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Column.html',1,'Column']]],
   ['columndescriptor_116',['ColumnDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1ColumnDescriptor.html',1,'com::sun::star::sdbcx']]],
   ['columndescriptorcontrol_117',['ColumnDescriptorControl',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnDescriptorControl.html',1,'com::sun::star::sdb']]],
   ['columndescriptorcontrolmodel_118',['ColumnDescriptorControlModel',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnDescriptorControlModel.html',1,'com::sun::star::sdb']]],
   ['columnsettings_119',['ColumnSettings',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html',1,'com::sun::star::sdb']]],
   ['combinedcharacters_120',['CombinedCharacters',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1CombinedCharacters.html',1,'com::sun::star::text::textfield']]],
-  ['combobox_121',['combobox',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1ComboBox.html',1,'ComboBox'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1ComboBox.html',1,'ComboBox']]],
-  ['command_122',['command',['../servicecom_1_1sun_1_1star_1_1animations_1_1Command.html',1,'Command'],['../structcom_1_1sun_1_1star_1_1ucb_1_1Command.html',1,'Command']]],
+  ['combobox_121',['ComboBox',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1ComboBox.html',1,'ComboBox'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1ComboBox.html',1,'ComboBox']]],
+  ['command_122',['Command',['../servicecom_1_1sun_1_1star_1_1animations_1_1Command.html',1,'Command'],['../structcom_1_1sun_1_1star_1_1ucb_1_1Command.html',1,'Command']]],
   ['commandabortedexception_123',['CommandAbortedException',['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1CommandAbortedException.html',1,'com::sun::star::ucb']]],
-  ['commandbutton_124',['commandbutton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1CommandButton.html',1,'CommandButton'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CommandButton.html',1,'CommandButton']]],
+  ['commandbutton_124',['CommandButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1CommandButton.html',1,'CommandButton'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CommandButton.html',1,'CommandButton']]],
   ['commanddefinition_125',['CommandDefinition',['../servicecom_1_1sun_1_1star_1_1sdb_1_1CommandDefinition.html',1,'com::sun::star::sdb']]],
   ['commandenvironment_126',['CommandEnvironment',['../servicecom_1_1sun_1_1star_1_1ucb_1_1CommandEnvironment.html',1,'com::sun::star::ucb']]],
   ['commandfailedexception_127',['CommandFailedException',['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1CommandFailedException.html',1,'com::sun::star::ucb']]],
@@ -144,7 +144,7 @@ var searchData=
   ['configurationregistry_141',['ConfigurationRegistry',['../servicecom_1_1sun_1_1star_1_1configuration_1_1ConfigurationRegistry.html',1,'com::sun::star::configuration']]],
   ['configurationupdateaccess_142',['ConfigurationUpdateAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1ConfigurationUpdateAccess.html',1,'com::sun::star::configuration']]],
   ['connectexception_143',['ConnectException',['../exceptioncom_1_1sun_1_1star_1_1io_1_1ConnectException.html',1,'com::sun::star::io']]],
-  ['connection_144',['connection',['../servicecom_1_1sun_1_1star_1_1sdb_1_1Connection.html',1,'Connection'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Connection.html',1,'Connection']]],
+  ['connection_144',['Connection',['../servicecom_1_1sun_1_1star_1_1sdb_1_1Connection.html',1,'Connection'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Connection.html',1,'Connection']]],
   ['connectionlostexception_145',['ConnectionLostException',['../exceptioncom_1_1sun_1_1star_1_1configuration_1_1backend_1_1ConnectionLostException.html',1,'com::sun::star::configuration::backend']]],
   ['connectionpool_146',['ConnectionPool',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1ConnectionPool.html',1,'com::sun::star::sdbc']]],
   ['connectionproperties_147',['ConnectionProperties',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1ConnectionProperties.html',1,'com::sun::star::sdbc']]],
@@ -197,15 +197,16 @@ var searchData=
   ['corrupteduiconfigurationexception_194',['CorruptedUIConfigurationException',['../exceptioncom_1_1sun_1_1star_1_1configuration_1_1CorruptedUIConfigurationException.html',1,'com::sun::star::configuration']]],
   ['createauthor_195',['CreateAuthor',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1CreateAuthor.html',1,'com::sun::star::text::textfield::docinfo']]],
   ['createdatetime_196',['CreateDateTime',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1CreateDateTime.html',1,'com::sun::star::text::textfield::docinfo']]],
-  ['crossreference_197',['CrossReference',['../structcom_1_1sun_1_1star_1_1ucb_1_1CrossReference.html',1,'com::sun::star::ucb']]],
-  ['cryptographyexception_198',['CryptographyException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1CryptographyException.html',1,'com::sun::star::security']]],
-  ['csvlogformatter_199',['CsvLogFormatter',['../servicecom_1_1sun_1_1star_1_1logging_1_1CsvLogFormatter.html',1,'com::sun::star::logging']]],
-  ['currency_200',['currency',['../structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Currency.html',1,'Currency'],['../structcom_1_1sun_1_1star_1_1i18n_1_1Currency.html',1,'Currency']]],
-  ['currency2_201',['Currency2',['../structcom_1_1sun_1_1star_1_1i18n_1_1Currency2.html',1,'com::sun::star::i18n']]],
-  ['currencyfield_202',['currencyfield',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1CurrencyField.html',1,'CurrencyField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CurrencyField.html',1,'CurrencyField']]],
-  ['custom_203',['Custom',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Custom.html',1,'com::sun::star::text::textfield::docinfo']]],
-  ['custompresentation_204',['CustomPresentation',['../servicecom_1_1sun_1_1star_1_1presentation_1_1CustomPresentation.html',1,'com::sun::star::presentation']]],
-  ['custompresentationaccess_205',['CustomPresentationAccess',['../servicecom_1_1sun_1_1star_1_1presentation_1_1CustomPresentationAccess.html',1,'com::sun::star::presentation']]],
-  ['customshape_206',['CustomShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html',1,'com::sun::star::drawing']]],
-  ['customshapeengine_207',['CustomShapeEngine',['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShapeEngine.html',1,'com::sun::star::drawing']]]
+  ['createdialogfactoryservice_197',['CreateDialogFactoryService',['../servicecom_1_1sun_1_1star_1_1presentation_1_1CreateDialogFactoryService.html',1,'CreateDialogFactoryService'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1CreateDialogFactoryService.html',1,'CreateDialogFactoryService']]],
+  ['crossreference_198',['CrossReference',['../structcom_1_1sun_1_1star_1_1ucb_1_1CrossReference.html',1,'com::sun::star::ucb']]],
+  ['cryptographyexception_199',['CryptographyException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1CryptographyException.html',1,'com::sun::star::security']]],
+  ['csvlogformatter_200',['CsvLogFormatter',['../servicecom_1_1sun_1_1star_1_1logging_1_1CsvLogFormatter.html',1,'com::sun::star::logging']]],
+  ['currency_201',['Currency',['../structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Currency.html',1,'Currency'],['../structcom_1_1sun_1_1star_1_1i18n_1_1Currency.html',1,'Currency']]],
+  ['currency2_202',['Currency2',['../structcom_1_1sun_1_1star_1_1i18n_1_1Currency2.html',1,'com::sun::star::i18n']]],
+  ['currencyfield_203',['CurrencyField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1CurrencyField.html',1,'CurrencyField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CurrencyField.html',1,'CurrencyField']]],
+  ['custom_204',['Custom',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Custom.html',1,'com::sun::star::text::textfield::docinfo']]],
+  ['custompresentation_205',['CustomPresentation',['../servicecom_1_1sun_1_1star_1_1presentation_1_1CustomPresentation.html',1,'com::sun::star::presentation']]],
+  ['custompresentationaccess_206',['CustomPresentationAccess',['../servicecom_1_1sun_1_1star_1_1presentation_1_1CustomPresentationAccess.html',1,'com::sun::star::presentation']]],
+  ['customshape_207',['CustomShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShape.html',1,'com::sun::star::drawing']]],
+  ['customshapeengine_208',['CustomShapeEngine',['../servicecom_1_1sun_1_1star_1_1drawing_1_1CustomShapeEngine.html',1,'com::sun::star::drawing']]]
 ];
