@@ -1,8 +1,8 @@
 var servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox =
 [
     [ "SelectedValues", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#a42bdf5f2c50db2116460a7425cacf207", null ],
-    [ "ListBox", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#ad3d2037514faca4e0814b8998a3ec427", null ],
-    [ "DataAwareControlModel", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#a53d9af822661deeb52eb09379d9805d4", null ],
+    [ "com::sun::star::form::component::ListBox", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#ad3d2037514faca4e0814b8998a3ec427", null ],
+    [ "com::sun::star::form::DataAwareControlModel", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#a53d9af822661deeb52eb09379d9805d4", null ],
     [ "BoundColumn", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#a619b718f466d907a6582423bfeb5b4da", null ],
     [ "ListSourceType", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#a2f99ac4d478a97752dfe0fac8cf8b232", null ],
     [ "SelectedValue", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#aa738687a1dba0c415179d0d832e7d23a", null ]
