@@ -1,7 +1,7 @@
 var servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules =
 [
-    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
-    [ "XIndexReplace", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a30efc34ee46bcbd9bdcdc5fad23706b3", null ],
+    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::container::XIndexReplace", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a30efc34ee46bcbd9bdcdc5fad23706b3", null ],
     [ "DefaultListId", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#ae1283571b6eec1e8879cad4010d56cfa", null ],
     [ "IsAbsoluteMargins", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a890f4747830984ac83c1c9e31f54cc91", null ],
     [ "IsAutomatic", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#aef8673876c856dba7a150226a26bc77d", null ],
